==> haskell-servant-client-core-0.19-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-client-core
version:              0.19
visibility:           public
id:                   servant-client-core-0.19-Ga4E44b1IDjJc5tYmJsI5Y
key:                  servant-client-core-0.19-Ga4E44b1IDjJc5tYmJsI5Y
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  cce64308bf3af7530af7fbfeadbc72b3
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Free Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/servant-client-core-0.19
library-dirs:         /usr/lib/ghc-9.0.2/site-local/servant-client-core-0.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client-core
hs-libraries:         HSservant-client-core-0.19-Ga4E44b1IDjJc5tYmJsI5Y
depends:
    aeson-2.1.1.0-6f0SUJ6dh2u49Oyg8vjVqb base-4.15.1.0
    base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    base64-bytestring-1.2.1.0-FAR0uALTIcmLdyhw4yH2vJ
    bytestring-0.10.12.1 constraints-0.13.4-CljVnGykyEPKrM7mPzCqJW
    containers-0.6.4.1 deepseq-1.4.5.0 exceptions-0.10.4
    free-5.1.10-E9Q8boeuiuSDb7lvFfiZ46
    http-media-0.8.0.0-1b7WtBfTq9Y6JsG4HrSvy
    http-types-0.12.3-Gv30C4XbnFXDWjcAoX4JUI
    network-uri-2.6.4.1-4FpmgFzRAF8F97n6lcYlg2
    safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q
    servant-0.19.1-19CkXv5XGFyFGwiAxiG9cp
    sop-core-0.5.0.2-3jnDWqiXqcyAzV81XsfWbk template-haskell-2.17.0.0
    text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-core-0.19-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-client-core
version:              0.19
visibility:           public
id:                   servant-client-core-0.19-9WifLMgpj3VFKYOyUmuEAY
key:                  servant-client-core-0.19-9WifLMgpj3VFKYOyUmuEAY
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  1ba1cb916a7d1e38bcc47809bccc902d
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Free Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/servant-client-core-0.19
library-dirs:         /usr/lib/ghc-9.0.2/site-local/servant-client-core-0.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client-core
hs-libraries:         HSservant-client-core-0.19-9WifLMgpj3VFKYOyUmuEAY
depends:
    aeson-2.1.1.0-K9BW85jPsWRAK2RMwS3bY2 base-4.15.1.0
    base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    base64-bytestring-1.2.1.0-4cRiweiLQA5F7M7qL12fiz
    bytestring-0.10.12.1 constraints-0.13.4-KvpdFgHaIdXCljRnOKXNVY
    containers-0.6.4.1 deepseq-1.4.5.0 exceptions-0.10.4
    free-5.1.10-7C6NAAeSiKJ8iNMmNxgt1s
    http-media-0.8.0.0-JlVCwNyVjXZFGV4bPUklGP
    http-types-0.12.3-KPLjBYBG4Ui6L5702lyKk2
    network-uri-2.6.4.1-6ZiP9eTaRPdCx8mZK7nGmp
    safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q
    servant-0.19.1-BcH8Hgqrs4hGCOElRU8n9B
    sop-core-0.5.0.2-3jnDWqiXqcyAzV81XsfWbk template-haskell-2.17.0.0
    text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
